==> mysql-community_8.3.0.orig.tar.gz: mysql-8.3.0/storage/ndb/tools/NdbToolsLogging.hpp <==
/*
   Copyright (c) 2019, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_TOOLS_LOGGING_HPP
#define NDB_TOOLS_LOGGING_HPP

#include <NdbOut.hpp>

#define NDB_ERR_OUT(where, error)                                           \
  {                                                                         \
    where << "ERROR: " << error.code << " " << error.message << endl        \
          << "           "                                                  \
          << "Status: " << error.status                                     \
          << ", Classification: " << error.classification << endl           \
          << "           "                                                  \
          << "File: " << __FILE__ << " (Line: " << __LINE__ << ")" << endl; \
  }

#define NDB_ERR(error)                \
  {                                   \
    const NdbError &_error = (error); \
    NDB_ERR_OUT(ndberr, _error);      \
  }

#endif  // NDB_TOOLS_LOGGING_HPP

==> mysql-community_9.5.0.orig.tar.gz: mysql-9.5.0/storage/ndb/tools/NdbToolsLogging.hpp <==
/*
   Copyright (c) 2019, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_TOOLS_LOGGING_HPP
#define NDB_TOOLS_LOGGING_HPP

#include <NdbOut.hpp>

#define NDB_ERR_OUT(where, error)                                           \
  {                                                                         \
    where << "ERROR: " << error.code << " " << error.message << endl        \
          << "           "                                                  \
          << "Status: " << error.status                                     \
          << ", Classification: " << error.classification << endl           \
          << "           "                                                  \
          << "File: " << __FILE__ << " (Line: " << __LINE__ << ")" << endl; \
  }

#define NDB_ERR(error)                \
  {                                   \
    const NdbError &_error = (error); \
    NDB_ERR_OUT(ndberr, _error);      \
  }

#endif  // NDB_TOOLS_LOGGING_HPP
